static

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 8, 2022 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Static

type Static struct {
}

The Static auto-discovery Provider is a bit of an oxymoron: it performs no discovery and returns the Prompt passed to it. Use it to include a list of Static prompts alongside other auto-discovered entries.

Filters

The Static Provider ignores all provided filters.

Sorting

The Static Provider ignores all provided sorting options.

func (*Static) Discover

func (provider *Static) Discover(queries []*jump.PromptQuery) ([]*jump.Prompt, error)

func (*Static) Initialize

func (provider *Static) Initialize(i interface{})

Jump to