Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Static ¶
type Static struct {
}
The Static auto-discovery Provider is a bit of an oxymoron: it performs no discovery and returns the Prompt passed to it. Use it to include a list of Static prompts alongside other auto-discovered entries.
Filters ¶
The Static Provider ignores all provided filters.
Sorting ¶
The Static Provider ignores all provided sorting options.
func (*Static) Initialize ¶
func (provider *Static) Initialize(i interface{})
Click to show internal directories.
Click to hide internal directories.